pub fn get_news_routes() -> Vec<SitemapEntry>Expand description
One entry per published news article, derived from the article registry so a new post can never be forgotten here.
pub fn get_news_routes() -> Vec<SitemapEntry>One entry per published news article, derived from the article registry so a new post can never be forgotten here.